AmMemory<T> extension

on
  • T

Methods

amGet(dynamic id) → T

Available on T, provided by the AmMemory extension

Returns the object saved and associated with this id; if nothing is saved it Returns this parent object;
amSave(dynamic id) → void

Available on T, provided by the AmMemory extension

to Save this object with an id;

Static Methods

amGetIfSaved<K>(dynamic id) → K?

Available on T, provided by the AmMemory extension

to Get the saved object associated with this id; Returns null if there is nothing saved;