AmTools class abstract

Constructors

AmTools()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

calculateMD5Hash(String inputString) String
Calculates the MD5 hash of the given String
calculateMD5HashFromBytes(Uint8List bytes) Future<String>
Calculates the MD5 hash of the given bytes Uint8List
calculateMD5HashFromFile(File file) Future<String>
Calculates the MD5 hash of the given File
genUniqueId() String
to generate unique id in milli seconds resolution
genUniqueIdMicro() String
to generate unique id in micro seconds resolution